@@ -256,15 +256,15 @@ class Client:
                 return
 
             redis_resp = self.execute(command_name, *args)
-            # if shell, do not render, just run in shell pipe and show the
+            # if shell_command and enable shell, do not render, just run in shell pipe and show the
             # subcommand's stdout/stderr
-            if shell_command:
+            if shell_command and config.shell:
                 # pass the raw response of redis to shell command
                 if isinstance(redis_resp, list):
                     stdin = b"\n".join(redis_resp)
                 else:
                     stdin = redis_resp
-                run(shell_command, input=stdin, stdout=sys.stdout, shell=True)
+                run(shell_command, input=stdin, shell=True)
                 return
 
             self.after_hook(raw_command, command_name, args, completer, redis_resp)
@@ -499,10 +499,16 @@ class Client:
             return
 
         encoding = nativestr(self.execute("object encoding", key))
-        memory_usage = str(self.execute("memory usage", key))
+
+        # use `memory usage` to get memory, this command available from redis4.0
+        mem = ""
+        if config.version and StrictVersion(config.version) >= StrictVersion("4.0.0"):
+            memory_usage_value = str(self.execute("memory usage", key))
+            mem = f"  mem: {memory_usage_value} bytes"
+
         ttl = str(self.execute("ttl", key))
 
-        key_info = f"{key_type} ({encoding})  mem: {memory_usage} bytes, ttl: {ttl}"
+        key_info = f"{key_type} ({encoding}){mem}, ttl: {ttl}"
 
         # FIXME raw write_result parse FormattedText
         yield FormattedText([("class:dockey", "key: "), ("", key_info)])
