@@ -37,6 +37,7 @@ class Config:
         self.decode = None
         self.no_info = None
         self.bottom_bar = None
+        self.shell = None
 
         self.warning = True
 
@@ -120,5 +121,6 @@ def load_config_files(iredisrc):
     config.completion_casing = config_obj["main"]["completion_casing"]
     config.history_location = config_obj["main"]["history_location"]
     config.alias_dsn = config_obj["alias_dsn"]
+    config.shell = config_obj["main"].as_bool("shell")
 
     return config_obj
