@@ -10,7 +10,7 @@ from distutils.version import StrictVersion
 
 from prompt_toolkit.formatted_text import FormattedText
 
-from .commands_csv_loader import command2callback
+from .commands import command2callback
 from .config import config
 from .utils import double_quotes, ensure_str, nativestr
 
@@ -47,7 +47,7 @@ class OutputRender:
 
         callback = getattr(OutputRender, callback_name)
         rendered = callback(response)
-        logger.info(f"[rendered] {rendered}")
+        logger.info(f"[render] using {callback_name}, result: {rendered}")
         return rendered
 
     @staticmethod
@@ -316,6 +316,10 @@ class OutputRender:
     def command_hkeys(response):
         return _update_completer_then_render(response, "class:field")
 
+    @staticmethod
+    def render_bytes(response):
+        return response.rstrip(b"\n")  # there is a new line in `write_result`
+
     @staticmethod
     def default_render(text):
         pass
